fn load_elf_into_task_static(
header: &ElfHeader,
file_obj: &dyn FileObject,
task: &Task,
strategy: &LoadStrategy,
) -> Result<u64, ElfLoaderError>Expand description
Load ELF using the static linking logic with strategy support
fn load_elf_into_task_static(
header: &ElfHeader,
file_obj: &dyn FileObject,
task: &Task,
strategy: &LoadStrategy,
) -> Result<u64, ElfLoaderError>Load ELF using the static linking logic with strategy support