setup_auxiliary_vector_on_stack

Function setup_auxiliary_vector_on_stack 

pub fn setup_auxiliary_vector_on_stack(
    task: &Task,
    auxv: &[AuxVec],
) -> Result<usize, ElfLoaderError>
Setup auxiliary vector on the task’s stack

This function places the auxiliary vector at the top of the stack, which is expected by the dynamic linker and C runtime.