LoadStrategy

Struct LoadStrategy 

pub struct LoadStrategy {
    pub choose_base_address: fn(target: LoadTarget, needs_relocation: bool) -> u64,
    pub resolve_interpreter: fn(requested: Option<&str>) -> Option<String>,
}
Binary loading strategy (format-agnostic)

This structure allows ABI modules to customize how binaries are loaded without being tied to specific binary formats like ELF.

Fields

choose_base_address: fn(target: LoadTarget, needs_relocation: bool) -> u64resolve_interpreter: fn(requested: Option<&str>) -> Option<String>